@@ -90,9 +90,9 @@ icalvalue_kind icalvalue_string_to_kind(const char* str)
 }
 
 icalvalue* icalvalue_new_x (const char* v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_X_VALUE);
+   struct icalvalue_impl* impl;
    icalerror_check_arg_rz( (v!=0),"v");
-
+   impl = icalvalue_new_impl(ICAL_X_VALUE);
    icalvalue_set_x((icalvalue*)impl,v);
    return (icalvalue*)impl;
 }
@@ -297,89 +297,67 @@ icalvalue_get_datetimeperiod(icalvalue* value)
 
 /* Everything below this line is machine generated. Do not edit. */
 static struct icalvalue_kind_map value_map[]={
-    {ICAL_DATETIMEDATE_VALUE,"DATE-TIME-DATE"},
-    {ICAL_CLASS_VALUE,"CLASS"},
-    {ICAL_BINARY_VALUE,"BINARY"},
-    {ICAL_QUERY_VALUE,"QUERY"},
-    {ICAL_TIME_VALUE,"TIME"},
-    {ICAL_DURATION_VALUE,"DURATION"},
-    {ICAL_UTCOFFSET_VALUE,"UTC-OFFSET"},
-    {ICAL_TRIGGER_VALUE,"TRIGGER"},
-    {ICAL_STRING_VALUE,"STRING"},
     {ICAL_ATTACH_VALUE,"ATTACH"},
-    {ICAL_TRANSP_VALUE,"TRANSP"},
-    {ICAL_BOOLEAN_VALUE,"BOOLEAN"},
+    {ICAL_BINARY_VALUE,"BINARY"},
     {ICAL_PERIOD_VALUE,"PERIOD"},
-    {ICAL_DATE_VALUE,"DATE"},
-    {ICAL_RECUR_VALUE,"RECUR"},
-    {ICAL_GEO_VALUE,"GEO"},
-    {ICAL_URI_VALUE,"URI"},
-    {ICAL_X_VALUE,"X"},
-    {ICAL_STATUS_VALUE,"STATUS"},
-    {ICAL_CALADDRESS_VALUE,"CAL-ADDRESS"},
-    {ICAL_DATETIMEPERIOD_VALUE,"DATE-TIME-PERIOD"},
-    {ICAL_METHOD_VALUE,"METHOD"},
-    {ICAL_ACTION_VALUE,"ACTION"},
-    {ICAL_FLOAT_VALUE,"FLOAT"},
-    {ICAL_INTEGER_VALUE,"INTEGER"},
-    {ICAL_DATETIME_VALUE,"DATE-TIME"},
+    {ICAL_DATETIMEDATE_VALUE,"DATE-TIME-DATE"},
     {ICAL_TEXT_VALUE,"TEXT"},
+    {ICAL_DATETIME_VALUE,"DATE-TIME"},
+    {ICAL_INTEGER_VALUE,"INTEGER"},
+    {ICAL_CLASS_VALUE,"CLASS"},
+    {ICAL_STRING_VALUE,"STRING"},
+    {ICAL_FLOAT_VALUE,"FLOAT"},
+    {ICAL_TIME_VALUE,"TIME"},
+    {ICAL_GEO_VALUE,"GEO"},
+    {ICAL_CALADDRESS_VALUE,"CAL-ADDRESS"},
+    {ICAL_RECUR_VALUE,"RECUR"},
+    {ICAL_UTCOFFSET_VALUE,"UTC-OFFSET"},
+    {ICAL_TRANSP_VALUE,"TRANSP"},
+    {ICAL_METHOD_VALUE,"METHOD"},
+    {ICAL_TRIGGER_VALUE,"TRIGGER"},
+    {ICAL_ACTION_VALUE,"ACTION"},
+    {ICAL_URI_VALUE,"URI"},
+    {ICAL_STATUS_VALUE,"STATUS"},
+    {ICAL_DATE_VALUE,"DATE"},
+    {ICAL_DURATION_VALUE,"DURATION"},
+    {ICAL_QUERY_VALUE,"QUERY"},
+    {ICAL_X_VALUE,"X"},
+    {ICAL_DATETIMEPERIOD_VALUE,"DATE-TIME-PERIOD"},
+    {ICAL_BOOLEAN_VALUE,"BOOLEAN"},
     {ICAL_NO_VALUE,""}
 };
 
 
-icalvalue* icalvalue_new_datetimedate (struct icaltimetype v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_DATETIMEDATE_VALUE);
+icalvalue* icalvalue_new_attach (struct icalattachtype v){
+   struct icalvalue_impl* impl;
    
-   icalvalue_set_datetimedate((icalvalue*)impl,v);
+   impl = icalvalue_new_impl(ICAL_ATTACH_VALUE);
+   icalvalue_set_attach((icalvalue*)impl,v);
    return (icalvalue*)impl;
 }
-void icalvalue_set_datetimedate(icalvalue* value, struct icaltimetype v) {
+void icalvalue_set_attach(icalvalue* value, struct icalattachtype v) {
     struct icalvalue_impl* impl; 
     icalerror_check_arg_rv( (value!=0),"value");
     
-    icalerror_check_value_type(value, ICAL_DATETIMEDATE_VALUE);
+    icalerror_check_value_type(value, ICAL_ATTACH_VALUE);
     impl = (struct icalvalue_impl*)value;
 
-    impl->data.v_time = v; 
+    impl->data.v_attach = v; 
  }
-struct icaltimetype icalvalue_get_datetimedate(icalvalue* value) {
+struct icalattachtype icalvalue_get_attach(icalvalue* value) {
 
 	icalerror_check_arg( (value!=0),"value");
-	icalerror_check_value_type(value, ICAL_DATETIMEDATE_VALUE);
-	return ((struct icalvalue_impl*)value)->data.v_time;
-}
-
-
-
-icalvalue* icalvalue_new_class (enum icalproperty_class v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_CLASS_VALUE);
-   
-   icalvalue_set_class((icalvalue*)impl,v);
-   return (icalvalue*)impl;
-}
-void icalvalue_set_class(icalvalue* value, enum icalproperty_class v) {
-    struct icalvalue_impl* impl; 
-    icalerror_check_arg_rv( (value!=0),"value");
-    
-    icalerror_check_value_type(value, ICAL_CLASS_VALUE);
-    impl = (struct icalvalue_impl*)value;
-
-    impl->data.v_enum = v; 
- }
-enum icalproperty_class icalvalue_get_class(icalvalue* value) {
-
-	icalerror_check_arg( (value!=0),"value");
-	icalerror_check_value_type(value, ICAL_CLASS_VALUE);
-	return ((struct icalvalue_impl*)value)->data.v_enum;
+	icalerror_check_value_type(value, ICAL_ATTACH_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_attach;
 }
 
 
 
 icalvalue* icalvalue_new_binary (const char* v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_BINARY_VALUE);
+   struct icalvalue_impl* impl;
    icalerror_check_arg_rz( (v!=0),"v");
 
+   impl = icalvalue_new_impl(ICAL_BINARY_VALUE);
    icalvalue_set_binary((icalvalue*)impl,v);
    return (icalvalue*)impl;
 }
@@ -408,19 +386,70 @@ const char* icalvalue_get_binary(icalvalue* value) {
 
 
 
-icalvalue* icalvalue_new_query (const char* v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_QUERY_VALUE);
-   icalerror_check_arg_rz( (v!=0),"v");
-
-   icalvalue_set_query((icalvalue*)impl,v);
+icalvalue* icalvalue_new_period (struct icalperiodtype v){
+   struct icalvalue_impl* impl;
+   
+   impl = icalvalue_new_impl(ICAL_PERIOD_VALUE);
+   icalvalue_set_period((icalvalue*)impl,v);
    return (icalvalue*)impl;
 }
-void icalvalue_set_query(icalvalue* value, const char* v) {
+void icalvalue_set_period(icalvalue* value, struct icalperiodtype v) {
+    struct icalvalue_impl* impl; 
+    icalerror_check_arg_rv( (value!=0),"value");
+    
+    icalerror_check_value_type(value, ICAL_PERIOD_VALUE);
+    impl = (struct icalvalue_impl*)value;
+
+    impl->data.v_period = v; 
+ }
+struct icalperiodtype icalvalue_get_period(icalvalue* value) {
+
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_PERIOD_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_period;
+}
+
+
+
+icalvalue* icalvalue_new_datetimedate (struct icaltimetype v){
+   struct icalvalue_impl* impl;
+   
+   impl = icalvalue_new_impl(ICAL_DATETIMEDATE_VALUE);
+   icalvalue_set_datetimedate((icalvalue*)impl,v);
+   return (icalvalue*)impl;
+}
+void icalvalue_set_datetimedate(icalvalue* value, struct icaltimetype v) {
+    struct icalvalue_impl* impl; 
+    icalerror_check_arg_rv( (value!=0),"value");
+    
+    icalerror_check_value_type(value, ICAL_DATETIMEDATE_VALUE);
+    impl = (struct icalvalue_impl*)value;
+
+    impl->data.v_time = v; 
+ }
+struct icaltimetype icalvalue_get_datetimedate(icalvalue* value) {
+
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_DATETIMEDATE_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_time;
+}
+
+
+
+icalvalue* icalvalue_new_text (const char* v){
+   struct icalvalue_impl* impl;
+   icalerror_check_arg_rz( (v!=0),"v");
+
+   impl = icalvalue_new_impl(ICAL_TEXT_VALUE);
+   icalvalue_set_text((icalvalue*)impl,v);
+   return (icalvalue*)impl;
+}
+void icalvalue_set_text(icalvalue* value, const char* v) {
     struct icalvalue_impl* impl; 
     icalerror_check_arg_rv( (value!=0),"value");
     icalerror_check_arg_rv( (v!=0),"v");
 
-    icalerror_check_value_type(value, ICAL_QUERY_VALUE);
+    icalerror_check_value_type(value, ICAL_TEXT_VALUE);
     impl = (struct icalvalue_impl*)value;
     if(impl->data.v_string!=0) {free((void*)impl->data.v_string);}
 
@@ -431,91 +460,95 @@ void icalvalue_set_query(icalvalue* value, const char* v) {
     }
  
  }
-const char* icalvalue_get_query(icalvalue* value) {
+const char* icalvalue_get_text(icalvalue* value) {
 
 	icalerror_check_arg_rz( (value!=0),"value");
-	icalerror_check_value_type(value, ICAL_QUERY_VALUE);
+	icalerror_check_value_type(value, ICAL_TEXT_VALUE);
 	return ((struct icalvalue_impl*)value)->data.v_string;
 }
 
 
 
-icalvalue* icalvalue_new_time (struct icaltimetype v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_TIME_VALUE);
+icalvalue* icalvalue_new_datetime (struct icaltimetype v){
+   struct icalvalue_impl* impl;
    
-   icalvalue_set_time((icalvalue*)impl,v);
+   impl = icalvalue_new_impl(ICAL_DATETIME_VALUE);
+   icalvalue_set_datetime((icalvalue*)impl,v);
    return (icalvalue*)impl;
 }
-void icalvalue_set_time(icalvalue* value, struct icaltimetype v) {
+void icalvalue_set_datetime(icalvalue* value, struct icaltimetype v) {
     struct icalvalue_impl* impl; 
     icalerror_check_arg_rv( (value!=0),"value");
     
-    icalerror_check_value_type(value, ICAL_TIME_VALUE);
+    icalerror_check_value_type(value, ICAL_DATETIME_VALUE);
     impl = (struct icalvalue_impl*)value;
 
     impl->data.v_time = v; 
  }
-struct icaltimetype icalvalue_get_time(icalvalue* value) {
+struct icaltimetype icalvalue_get_datetime(icalvalue* value) {
 
 	icalerror_check_arg( (value!=0),"value");
-	icalerror_check_value_type(value, ICAL_TIME_VALUE);
+	icalerror_check_value_type(value, ICAL_DATETIME_VALUE);
 	return ((struct icalvalue_impl*)value)->data.v_time;
 }
 
 
 
-icalvalue* icalvalue_new_duration (struct icaldurationtype v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_DURATION_VALUE);
+icalvalue* icalvalue_new_integer (int v){
+   struct icalvalue_impl* impl;
    
-   icalvalue_set_duration((icalvalue*)impl,v);
+   impl = icalvalue_new_impl(ICAL_INTEGER_VALUE);
+   icalvalue_set_integer((icalvalue*)impl,v);
    return (icalvalue*)impl;
 }
-void icalvalue_set_duration(icalvalue* value, struct icaldurationtype v) {
+void icalvalue_set_integer(icalvalue* value, int v) {
     struct icalvalue_impl* impl; 
     icalerror_check_arg_rv( (value!=0),"value");
     
-    icalerror_check_value_type(value, ICAL_DURATION_VALUE);
-    impl = (struct icalvalue_impl*)value;
-
-    impl->data.v_duration = v; 
- }
-struct icaldurationtype icalvalue_get_duration(icalvalue* value) {
-
-	icalerror_check_arg( (value!=0),"value");
-	icalerror_check_value_type(value, ICAL_DURATION_VALUE);
-	return ((struct icalvalue_impl*)value)->data.v_duration;
-}
-
-
-
-icalvalue* icalvalue_new_utcoffset (int v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_UTCOFFSET_VALUE);
-   
-   icalvalue_set_utcoffset((icalvalue*)impl,v);
-   return (icalvalue*)impl;
-}
-void icalvalue_set_utcoffset(icalvalue* value, int v) {
-    struct icalvalue_impl* impl; 
-    icalerror_check_arg_rv( (value!=0),"value");
-    
-    icalerror_check_value_type(value, ICAL_UTCOFFSET_VALUE);
+    icalerror_check_value_type(value, ICAL_INTEGER_VALUE);
     impl = (struct icalvalue_impl*)value;
 
     impl->data.v_int = v; 
  }
-int icalvalue_get_utcoffset(icalvalue* value) {
+int icalvalue_get_integer(icalvalue* value) {
 
 	icalerror_check_arg( (value!=0),"value");
-	icalerror_check_value_type(value, ICAL_UTCOFFSET_VALUE);
+	icalerror_check_value_type(value, ICAL_INTEGER_VALUE);
 	return ((struct icalvalue_impl*)value)->data.v_int;
 }
 
 
 
+icalvalue* icalvalue_new_class (enum icalproperty_class v){
+   struct icalvalue_impl* impl;
+   
+   impl = icalvalue_new_impl(ICAL_CLASS_VALUE);
+   icalvalue_set_class((icalvalue*)impl,v);
+   return (icalvalue*)impl;
+}
+void icalvalue_set_class(icalvalue* value, enum icalproperty_class v) {
+    struct icalvalue_impl* impl; 
+    icalerror_check_arg_rv( (value!=0),"value");
+    
+    icalerror_check_value_type(value, ICAL_CLASS_VALUE);
+    impl = (struct icalvalue_impl*)value;
+
+    impl->data.v_enum = v; 
+ }
+enum icalproperty_class icalvalue_get_class(icalvalue* value) {
+
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_CLASS_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_enum;
+}
+
+
+
 icalvalue* icalvalue_new_string (const char* v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_STRING_VALUE);
+   struct icalvalue_impl* impl;
    icalerror_check_arg_rz( (v!=0),"v");
 
+   impl = icalvalue_new_impl(ICAL_STRING_VALUE);
    icalvalue_set_string((icalvalue*)impl,v);
    return (icalvalue*)impl;
 }
@@ -544,129 +577,60 @@ const char* icalvalue_get_string(icalvalue* value) {
 
 
 
-icalvalue* icalvalue_new_attach (struct icalattachtype v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_ATTACH_VALUE);
+icalvalue* icalvalue_new_float (float v){
+   struct icalvalue_impl* impl;
    
-   icalvalue_set_attach((icalvalue*)impl,v);
+   impl = icalvalue_new_impl(ICAL_FLOAT_VALUE);
+   icalvalue_set_float((icalvalue*)impl,v);
    return (icalvalue*)impl;
 }
-void icalvalue_set_attach(icalvalue* value, struct icalattachtype v) {
+void icalvalue_set_float(icalvalue* value, float v) {
     struct icalvalue_impl* impl; 
     icalerror_check_arg_rv( (value!=0),"value");
     
-    icalerror_check_value_type(value, ICAL_ATTACH_VALUE);
+    icalerror_check_value_type(value, ICAL_FLOAT_VALUE);
     impl = (struct icalvalue_impl*)value;
 
-    impl->data.v_attach = v; 
+    impl->data.v_float = v; 
  }
-struct icalattachtype icalvalue_get_attach(icalvalue* value) {
+float icalvalue_get_float(icalvalue* value) {
 
 	icalerror_check_arg( (value!=0),"value");
-	icalerror_check_value_type(value, ICAL_ATTACH_VALUE);
-	return ((struct icalvalue_impl*)value)->data.v_attach;
+	icalerror_check_value_type(value, ICAL_FLOAT_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_float;
 }
 
 
 
-icalvalue* icalvalue_new_transp (enum icalproperty_transp v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_TRANSP_VALUE);
+icalvalue* icalvalue_new_time (struct icaltimetype v){
+   struct icalvalue_impl* impl;
    
-   icalvalue_set_transp((icalvalue*)impl,v);
+   impl = icalvalue_new_impl(ICAL_TIME_VALUE);
+   icalvalue_set_time((icalvalue*)impl,v);
    return (icalvalue*)impl;
 }
-void icalvalue_set_transp(icalvalue* value, enum icalproperty_transp v) {
+void icalvalue_set_time(icalvalue* value, struct icaltimetype v) {
     struct icalvalue_impl* impl; 
     icalerror_check_arg_rv( (value!=0),"value");
     
-    icalerror_check_value_type(value, ICAL_TRANSP_VALUE);
-    impl = (struct icalvalue_impl*)value;
-
-    impl->data.v_enum = v; 
- }
-enum icalproperty_transp icalvalue_get_transp(icalvalue* value) {
-
-	icalerror_check_arg( (value!=0),"value");
-	icalerror_check_value_type(value, ICAL_TRANSP_VALUE);
-	return ((struct icalvalue_impl*)value)->data.v_enum;
-}
-
-
-
-icalvalue* icalvalue_new_boolean (int v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_BOOLEAN_VALUE);
-   
-   icalvalue_set_boolean((icalvalue*)impl,v);
-   return (icalvalue*)impl;
-}
-void icalvalue_set_boolean(icalvalue* value, int v) {
-    struct icalvalue_impl* impl; 
-    icalerror_check_arg_rv( (value!=0),"value");
-    
-    icalerror_check_value_type(value, ICAL_BOOLEAN_VALUE);
-    impl = (struct icalvalue_impl*)value;
-
-    impl->data.v_int = v; 
- }
-int icalvalue_get_boolean(icalvalue* value) {
-
-	icalerror_check_arg( (value!=0),"value");
-	icalerror_check_value_type(value, ICAL_BOOLEAN_VALUE);
-	return ((struct icalvalue_impl*)value)->data.v_int;
-}
-
-
-
-icalvalue* icalvalue_new_period (struct icalperiodtype v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_PERIOD_VALUE);
-   
-   icalvalue_set_period((icalvalue*)impl,v);
-   return (icalvalue*)impl;
-}
-void icalvalue_set_period(icalvalue* value, struct icalperiodtype v) {
-    struct icalvalue_impl* impl; 
-    icalerror_check_arg_rv( (value!=0),"value");
-    
-    icalerror_check_value_type(value, ICAL_PERIOD_VALUE);
-    impl = (struct icalvalue_impl*)value;
-
-    impl->data.v_period = v; 
- }
-struct icalperiodtype icalvalue_get_period(icalvalue* value) {
-
-	icalerror_check_arg( (value!=0),"value");
-	icalerror_check_value_type(value, ICAL_PERIOD_VALUE);
-	return ((struct icalvalue_impl*)value)->data.v_period;
-}
-
-
-
-icalvalue* icalvalue_new_date (struct icaltimetype v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_DATE_VALUE);
-   
-   icalvalue_set_date((icalvalue*)impl,v);
-   return (icalvalue*)impl;
-}
-void icalvalue_set_date(icalvalue* value, struct icaltimetype v) {
-    struct icalvalue_impl* impl; 
-    icalerror_check_arg_rv( (value!=0),"value");
-    
-    icalerror_check_value_type(value, ICAL_DATE_VALUE);
+    icalerror_check_value_type(value, ICAL_TIME_VALUE);
     impl = (struct icalvalue_impl*)value;
 
     impl->data.v_time = v; 
  }
-struct icaltimetype icalvalue_get_date(icalvalue* value) {
+struct icaltimetype icalvalue_get_time(icalvalue* value) {
 
 	icalerror_check_arg( (value!=0),"value");
-	icalerror_check_value_type(value, ICAL_DATE_VALUE);
+	icalerror_check_value_type(value, ICAL_TIME_VALUE);
 	return ((struct icalvalue_impl*)value)->data.v_time;
 }
 
 
 
 icalvalue* icalvalue_new_geo (struct icalgeotype v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_GEO_VALUE);
+   struct icalvalue_impl* impl;
    
+   impl = icalvalue_new_impl(ICAL_GEO_VALUE);
    icalvalue_set_geo((icalvalue*)impl,v);
    return (icalvalue*)impl;
 }
@@ -688,10 +652,144 @@ struct icalgeotype icalvalue_get_geo(icalvalue* value) {
 
 
 
-icalvalue* icalvalue_new_uri (const char* v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_URI_VALUE);
+icalvalue* icalvalue_new_caladdress (const char* v){
+   struct icalvalue_impl* impl;
    icalerror_check_arg_rz( (v!=0),"v");
 
+   impl = icalvalue_new_impl(ICAL_CALADDRESS_VALUE);
+   icalvalue_set_caladdress((icalvalue*)impl,v);
+   return (icalvalue*)impl;
+}
+void icalvalue_set_caladdress(icalvalue* value, const char* v) {
+    struct icalvalue_impl* impl; 
+    icalerror_check_arg_rv( (value!=0),"value");
+    icalerror_check_arg_rv( (v!=0),"v");
+
+    icalerror_check_value_type(value, ICAL_CALADDRESS_VALUE);
+    impl = (struct icalvalue_impl*)value;
+    if(impl->data.v_string!=0) {free((void*)impl->data.v_string);}
+
+    impl->data.v_string = icalmemory_strdup(v);
+
+    if (impl->data.v_string == 0){
+      errno = ENOMEM;
+    }
+ 
+ }
+const char* icalvalue_get_caladdress(icalvalue* value) {
+
+	icalerror_check_arg_rz( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_CALADDRESS_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_string;
+}
+
+
+
+icalvalue* icalvalue_new_utcoffset (int v){
+   struct icalvalue_impl* impl;
+   
+   impl = icalvalue_new_impl(ICAL_UTCOFFSET_VALUE);
+   icalvalue_set_utcoffset((icalvalue*)impl,v);
+   return (icalvalue*)impl;
+}
+void icalvalue_set_utcoffset(icalvalue* value, int v) {
+    struct icalvalue_impl* impl; 
+    icalerror_check_arg_rv( (value!=0),"value");
+    
+    icalerror_check_value_type(value, ICAL_UTCOFFSET_VALUE);
+    impl = (struct icalvalue_impl*)value;
+
+    impl->data.v_int = v; 
+ }
+int icalvalue_get_utcoffset(icalvalue* value) {
+
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_UTCOFFSET_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_int;
+}
+
+
+
+icalvalue* icalvalue_new_transp (enum icalproperty_transp v){
+   struct icalvalue_impl* impl;
+   
+   impl = icalvalue_new_impl(ICAL_TRANSP_VALUE);
+   icalvalue_set_transp((icalvalue*)impl,v);
+   return (icalvalue*)impl;
+}
+void icalvalue_set_transp(icalvalue* value, enum icalproperty_transp v) {
+    struct icalvalue_impl* impl; 
+    icalerror_check_arg_rv( (value!=0),"value");
+    
+    icalerror_check_value_type(value, ICAL_TRANSP_VALUE);
+    impl = (struct icalvalue_impl*)value;
+
+    impl->data.v_enum = v; 
+ }
+enum icalproperty_transp icalvalue_get_transp(icalvalue* value) {
+
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_TRANSP_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_enum;
+}
+
+
+
+icalvalue* icalvalue_new_method (enum icalproperty_method v){
+   struct icalvalue_impl* impl;
+   
+   impl = icalvalue_new_impl(ICAL_METHOD_VALUE);
+   icalvalue_set_method((icalvalue*)impl,v);
+   return (icalvalue*)impl;
+}
+void icalvalue_set_method(icalvalue* value, enum icalproperty_method v) {
+    struct icalvalue_impl* impl; 
+    icalerror_check_arg_rv( (value!=0),"value");
+    
+    icalerror_check_value_type(value, ICAL_METHOD_VALUE);
+    impl = (struct icalvalue_impl*)value;
+
+    impl->data.v_enum = v; 
+ }
+enum icalproperty_method icalvalue_get_method(icalvalue* value) {
+
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_METHOD_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_enum;
+}
+
+
+
+icalvalue* icalvalue_new_action (enum icalproperty_action v){
+   struct icalvalue_impl* impl;
+   
+   impl = icalvalue_new_impl(ICAL_ACTION_VALUE);
+   icalvalue_set_action((icalvalue*)impl,v);
+   return (icalvalue*)impl;
+}
+void icalvalue_set_action(icalvalue* value, enum icalproperty_action v) {
+    struct icalvalue_impl* impl; 
+    icalerror_check_arg_rv( (value!=0),"value");
+    
+    icalerror_check_value_type(value, ICAL_ACTION_VALUE);
+    impl = (struct icalvalue_impl*)value;
+
+    impl->data.v_enum = v; 
+ }
+enum icalproperty_action icalvalue_get_action(icalvalue* value) {
+
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_ACTION_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_enum;
+}
+
+
+
+icalvalue* icalvalue_new_uri (const char* v){
+   struct icalvalue_impl* impl;
+   icalerror_check_arg_rz( (v!=0),"v");
+
+   impl = icalvalue_new_impl(ICAL_URI_VALUE);
    icalvalue_set_uri((icalvalue*)impl,v);
    return (icalvalue*)impl;
 }
@@ -721,8 +819,9 @@ const char* icalvalue_get_uri(icalvalue* value) {
 
 
 icalvalue* icalvalue_new_status (enum icalproperty_status v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_STATUS_VALUE);
+   struct icalvalue_impl* impl;
    
+   impl = icalvalue_new_impl(ICAL_STATUS_VALUE);
    icalvalue_set_status((icalvalue*)impl,v);
    return (icalvalue*)impl;
 }
@@ -744,171 +843,70 @@ enum icalproperty_status icalvalue_get_status(icalvalue* value) {
 
 
 
-icalvalue* icalvalue_new_caladdress (const char* v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_CALADDRESS_VALUE);
-   icalerror_check_arg_rz( (v!=0),"v");
-
-   icalvalue_set_caladdress((icalvalue*)impl,v);
-   return (icalvalue*)impl;
-}
-void icalvalue_set_caladdress(icalvalue* value, const char* v) {
-    struct icalvalue_impl* impl; 
-    icalerror_check_arg_rv( (value!=0),"value");
-    icalerror_check_arg_rv( (v!=0),"v");
-
-    icalerror_check_value_type(value, ICAL_CALADDRESS_VALUE);
-    impl = (struct icalvalue_impl*)value;
-    if(impl->data.v_string!=0) {free((void*)impl->data.v_string);}
-
-    impl->data.v_string = icalmemory_strdup(v);
-
-    if (impl->data.v_string == 0){
-      errno = ENOMEM;
-    }
- 
- }
-const char* icalvalue_get_caladdress(icalvalue* value) {
-
-	icalerror_check_arg_rz( (value!=0),"value");
-	icalerror_check_value_type(value, ICAL_CALADDRESS_VALUE);
-	return ((struct icalvalue_impl*)value)->data.v_string;
-}
-
-
-
-icalvalue* icalvalue_new_method (enum icalproperty_method v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_METHOD_VALUE);
+icalvalue* icalvalue_new_date (struct icaltimetype v){
+   struct icalvalue_impl* impl;
    
-   icalvalue_set_method((icalvalue*)impl,v);
+   impl = icalvalue_new_impl(ICAL_DATE_VALUE);
+   icalvalue_set_date((icalvalue*)impl,v);
    return (icalvalue*)impl;
 }
-void icalvalue_set_method(icalvalue* value, enum icalproperty_method v) {
+void icalvalue_set_date(icalvalue* value, struct icaltimetype v) {
     struct icalvalue_impl* impl; 
     icalerror_check_arg_rv( (value!=0),"value");
     
-    icalerror_check_value_type(value, ICAL_METHOD_VALUE);
-    impl = (struct icalvalue_impl*)value;
-
-    impl->data.v_enum = v; 
- }
-enum icalproperty_method icalvalue_get_method(icalvalue* value) {
-
-	icalerror_check_arg( (value!=0),"value");
-	icalerror_check_value_type(value, ICAL_METHOD_VALUE);
-	return ((struct icalvalue_impl*)value)->data.v_enum;
-}
-
-
-
-icalvalue* icalvalue_new_action (enum icalproperty_action v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_ACTION_VALUE);
-   
-   icalvalue_set_action((icalvalue*)impl,v);
-   return (icalvalue*)impl;
-}
-void icalvalue_set_action(icalvalue* value, enum icalproperty_action v) {
-    struct icalvalue_impl* impl; 
-    icalerror_check_arg_rv( (value!=0),"value");
-    
-    icalerror_check_value_type(value, ICAL_ACTION_VALUE);
-    impl = (struct icalvalue_impl*)value;
-
-    impl->data.v_enum = v; 
- }
-enum icalproperty_action icalvalue_get_action(icalvalue* value) {
-
-	icalerror_check_arg( (value!=0),"value");
-	icalerror_check_value_type(value, ICAL_ACTION_VALUE);
-	return ((struct icalvalue_impl*)value)->data.v_enum;
-}
-
-
-
-icalvalue* icalvalue_new_float (float v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_FLOAT_VALUE);
-   
-   icalvalue_set_float((icalvalue*)impl,v);
-   return (icalvalue*)impl;
-}
-void icalvalue_set_float(icalvalue* value, float v) {
-    struct icalvalue_impl* impl; 
-    icalerror_check_arg_rv( (value!=0),"value");
-    
-    icalerror_check_value_type(value, ICAL_FLOAT_VALUE);
-    impl = (struct icalvalue_impl*)value;
-
-    impl->data.v_float = v; 
- }
-float icalvalue_get_float(icalvalue* value) {
-
-	icalerror_check_arg( (value!=0),"value");
-	icalerror_check_value_type(value, ICAL_FLOAT_VALUE);
-	return ((struct icalvalue_impl*)value)->data.v_float;
-}
-
-
-
-icalvalue* icalvalue_new_integer (int v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_INTEGER_VALUE);
-   
-   icalvalue_set_integer((icalvalue*)impl,v);
-   return (icalvalue*)impl;
-}
-void icalvalue_set_integer(icalvalue* value, int v) {
-    struct icalvalue_impl* impl; 
-    icalerror_check_arg_rv( (value!=0),"value");
-    
-    icalerror_check_value_type(value, ICAL_INTEGER_VALUE);
-    impl = (struct icalvalue_impl*)value;
-
-    impl->data.v_int = v; 
- }
-int icalvalue_get_integer(icalvalue* value) {
-
-	icalerror_check_arg( (value!=0),"value");
-	icalerror_check_value_type(value, ICAL_INTEGER_VALUE);
-	return ((struct icalvalue_impl*)value)->data.v_int;
-}
-
-
-
-icalvalue* icalvalue_new_datetime (struct icaltimetype v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_DATETIME_VALUE);
-   
-   icalvalue_set_datetime((icalvalue*)impl,v);
-   return (icalvalue*)impl;
-}
-void icalvalue_set_datetime(icalvalue* value, struct icaltimetype v) {
-    struct icalvalue_impl* impl; 
-    icalerror_check_arg_rv( (value!=0),"value");
-    
-    icalerror_check_value_type(value, ICAL_DATETIME_VALUE);
+    icalerror_check_value_type(value, ICAL_DATE_VALUE);
     impl = (struct icalvalue_impl*)value;
 
     impl->data.v_time = v; 
  }
-struct icaltimetype icalvalue_get_datetime(icalvalue* value) {
+struct icaltimetype icalvalue_get_date(icalvalue* value) {
 
 	icalerror_check_arg( (value!=0),"value");
-	icalerror_check_value_type(value, ICAL_DATETIME_VALUE);
+	icalerror_check_value_type(value, ICAL_DATE_VALUE);
 	return ((struct icalvalue_impl*)value)->data.v_time;
 }
 
 
 
-icalvalue* icalvalue_new_text (const char* v){
-   struct icalvalue_impl* impl = icalvalue_new_impl(ICAL_TEXT_VALUE);
-   icalerror_check_arg_rz( (v!=0),"v");
-
-   icalvalue_set_text((icalvalue*)impl,v);
+icalvalue* icalvalue_new_duration (struct icaldurationtype v){
+   struct icalvalue_impl* impl;
+   
+   impl = icalvalue_new_impl(ICAL_DURATION_VALUE);
+   icalvalue_set_duration((icalvalue*)impl,v);
    return (icalvalue*)impl;
 }
-void icalvalue_set_text(icalvalue* value, const char* v) {
+void icalvalue_set_duration(icalvalue* value, struct icaldurationtype v) {
+    struct icalvalue_impl* impl; 
+    icalerror_check_arg_rv( (value!=0),"value");
+    
+    icalerror_check_value_type(value, ICAL_DURATION_VALUE);
+    impl = (struct icalvalue_impl*)value;
+
+    impl->data.v_duration = v; 
+ }
+struct icaldurationtype icalvalue_get_duration(icalvalue* value) {
+
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_DURATION_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_duration;
+}
+
+
+
+icalvalue* icalvalue_new_query (const char* v){
+   struct icalvalue_impl* impl;
+   icalerror_check_arg_rz( (v!=0),"v");
+
+   impl = icalvalue_new_impl(ICAL_QUERY_VALUE);
+   icalvalue_set_query((icalvalue*)impl,v);
+   return (icalvalue*)impl;
+}
+void icalvalue_set_query(icalvalue* value, const char* v) {
     struct icalvalue_impl* impl; 
     icalerror_check_arg_rv( (value!=0),"value");
     icalerror_check_arg_rv( (v!=0),"v");
 
-    icalerror_check_value_type(value, ICAL_TEXT_VALUE);
+    icalerror_check_value_type(value, ICAL_QUERY_VALUE);
     impl = (struct icalvalue_impl*)value;
     if(impl->data.v_string!=0) {free((void*)impl->data.v_string);}
 
@@ -919,9 +917,34 @@ void icalvalue_set_text(icalvalue* value, const char* v) {
     }
  
  }
-const char* icalvalue_get_text(icalvalue* value) {
+const char* icalvalue_get_query(icalvalue* value) {
 
 	icalerror_check_arg_rz( (value!=0),"value");
-	icalerror_check_value_type(value, ICAL_TEXT_VALUE);
+	icalerror_check_value_type(value, ICAL_QUERY_VALUE);
 	return ((struct icalvalue_impl*)value)->data.v_string;
 }
+
+
+
+icalvalue* icalvalue_new_boolean (int v){
+   struct icalvalue_impl* impl;
+   
+   impl = icalvalue_new_impl(ICAL_BOOLEAN_VALUE);
+   icalvalue_set_boolean((icalvalue*)impl,v);
+   return (icalvalue*)impl;
+}
+void icalvalue_set_boolean(icalvalue* value, int v) {
+    struct icalvalue_impl* impl; 
+    icalerror_check_arg_rv( (value!=0),"value");
+    
+    icalerror_check_value_type(value, ICAL_BOOLEAN_VALUE);
+    impl = (struct icalvalue_impl*)value;
+
+    impl->data.v_int = v; 
+ }
+int icalvalue_get_boolean(icalvalue* value) {
+
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_BOOLEAN_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_int;
+}
